**********
Monitoring
**********

Oríon provides command line tools to help monitoring status of experiments and inspect
available experiments in a database. The library API can also be used to query the database
within python code.

Commands for terminal
=====================

.. _cli-info:
.. include:: cli/list.rst
.. include:: cli/status.rst
.. include:: cli/info.rst

Library API
===========

.. _library-api-results:
.. include:: library/results.rst

.. _library-api-evc-results:
.. include:: library/evc_results.rst
